# SPDX-License-Identifier: CC0-1.0

{ system, legacyPackages, depot, apps }:

let
  inherit (legacyPackages) callPackage;

  dhallPackages = legacyPackages.dhallPackages // (callPackage ./dhall { });

  mkDhallManifest = drv:
    legacyPackages.runCommand "${drv.name}.dhall" { inherit drv; }
    "${apps.generate-manifest.program} $drv > $out";

  addManifest = drv: { manifest = mkDhallManifest drv; } // drv;

  callPackage' = path: attrs:
    addManifest (legacyPackages.callPackages path attrs);

in rec {

  inherit (legacyPackages) stdenv;

  bender = legacyPackages.buildPackages.callPackage ./bender { };

  dhallGenode = dhallPackages.genode;

  dhallPrelude = dhallPackages.prelude;

  genode = import ./genode {
    nixpkgs = legacyPackages;
    inherit mkDhallManifest;
  };

  NOVA = legacyPackages.callPackage ./NOVA { };

  libc = callPackage' ./libc { inherit depot; };

  nic_bus = callPackage ./nic_bus { inherit (genode) base os; };

  solo5 = let drv = callPackage' ./solo5 { inherit genode; };
  in drv // { tests = addManifest drv.tests // { pname = "solo5-tests"; }; };

  sotest-producer = callPackage' ./sotest-producer {
    stdenv = genode.stdenvGcc;
    inherit genode;
  };

  stdcxx = callPackage' ./stdcxx { };

}
